@@ -112,7 +112,6 @@ pub use self::{
     parser::*,
 };
 use serde::{Deserialize, Serialize};
-use swc_common::Span;
 pub use swc_ecma_ast::EsVersion as JscTarget;
 
 #[macro_use]
@@ -412,7 +411,6 @@ pub struct Context {
     in_type: bool,
     /// Typescript extension.
     in_declare: bool,
-    span_of_fn_name: Option<Span>,
 
     /// If true, `:` should not be treated as a type annotation.
     in_cond_expr: bool,
@@ -423,8 +421,6 @@ pub struct Context {
     in_parameters: bool,
 
     has_super_class: bool,
-    in_method: bool,
-    in_class_prop: bool,
 
     in_property_name: bool,
 
